@@ -193,10 +193,10 @@ static GtkToggleActionEntry action_toggle_entries[] = {
 	  N_("View the statusbar"),
 	  G_CALLBACK (activate_action_view_statusbar),
 	  TRUE },
-	{ "ViewFolders", NULL,
-	  N_("_Folders"), "F9",
-	  N_("View the folders pane"),
-	  G_CALLBACK (activate_action_view_folders),
+	{ "ViewSidebar", NULL,
+	  N_("_Sidebar"), "F9",
+	  N_("View the sidebar"),
+	  G_CALLBACK (activate_action_view_sidebar),
 	  FALSE },
 	{ "Find", GTK_STOCK_FIND,
 	  N_("Find…"), NULL,
